@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -45,6 +45,8 @@ use Predis\Command\Redis\Container\FunctionContainer;
 use Predis\Command\Redis\Container\Json\JSONDEBUG;
 use Predis\Command\Redis\Container\Search\FTCONFIG;
 use Predis\Command\Redis\Container\Search\FTCURSOR;
+use Predis\Command\Redis\HGETEX;
+use Predis\Command\Redis\HSETEX;
 use Predis\Configuration\OptionsInterface;
 use Predis\Connection\ConnectionInterface;
 use Predis\Response\Status;
@@ -74,8 +76,8 @@ use Predis\Response\Status;
  * @method string|null       randomkey()
  * @method mixed             rename(string $key, string $target)
  * @method int               renamenx(string $key, string $target)
- * @method array             scan($cursor, array $options = null)
- * @method array             sort(string $key, array $options = null)
+ * @method array             scan($cursor, ?array $options = null)
+ * @method array             sort(string $key, ?array $options = null)
  * @method array             sort_ro(string $key, ?string $byPattern = null, ?LimitOffsetCount $limit = null, array $getPatterns = [], ?string $sorting = null, bool $alpha = false)
  * @method int               ttl(string $key)
  * @method mixed             type(string $key)
@@ -92,6 +94,7 @@ use Predis\Response\Status;
  * @method int               bitcount(string $key, $start = null, $end = null, string $index = 'byte')
  * @method int               bitop($operation, $destkey, $key)
  * @method array|null        bitfield(string $key, $subcommand, ...$subcommandArg)
+ * @method array|null        bitfield_ro(string $key, ?array $encodingOffsetMap = null)
  * @method int               bitpos(string $key, $bit, $start = null, $end = null, string $index = 'byte')
  * @method array             blmpop(int $timeout, array $keys, string $modifier = 'left', int $count = 1)
  * @method array             bzpopmax(array $keys, int $timeout)
@@ -109,7 +112,7 @@ use Predis\Response\Status;
  * @method array             cfinsertnx(string $key, int $capacity = -1, bool $noCreate = false, string ...$item)
  * @method Status            cfreserve(string $key, int $capacity, int $bucketSize = -1, int $maxIterations = -1, int $expansion = -1)
  * @method array             cfscandump(string $key, int $iterator)
- * @method array             cmsincrby(string $key, string|int...$itemIncrementDictionary)
+ * @method array             cmsincrby(string $key, string|int ...$itemIncrementDictionary)
  * @method array             cmsinfo(string $key)
  * @method Status            cmsinitbydim(string $key, int $width, int $depth)
  * @method Status            cmsinitbyprob(string $key, float $errorRate, float $probability)
@@ -120,6 +123,7 @@ use Predis\Response\Status;
  * @method Status            failover(?To $to = null, bool $abort = false, int $timeout = -1)
  * @method mixed             fcall(string $function, array $keys, ...$args)
  * @method mixed             fcall_ro(string $function, array $keys, ...$args)
+ * @method array             ft_list()
  * @method array             ftaggregate(string $index, string $query, ?AggregateArguments $arguments = null)
  * @method Status            ftaliasadd(string $alias, string $index)
  * @method Status            ftaliasdel(string $alias)
@@ -155,7 +159,7 @@ use Predis\Response\Status;
  * @method mixed             mset(array $dictionary)
  * @method int               msetnx(array $dictionary)
  * @method Status            psetex(string $key, $milliseconds, $value)
- * @method Status            set(string $key, $value, $expireResolution = null, $expireTTL = null, $flag = null)
+ * @method Status|null       set(string $key, $value, $expireResolution = null, $expireTTL = null, $flag = null)
  * @method int               setbit(string $key, $offset, $value)
  * @method Status            setex(string $key, $seconds, $value)
  * @method int               setnx(string $key, $value)
@@ -163,8 +167,17 @@ use Predis\Response\Status;
  * @method int               strlen(string $key)
  * @method int               hdel(string $key, array $fields)
  * @method int               hexists(string $key, string $field)
+ * @method array|null        hexpire(string $key, int $seconds, array $fields, string $flag = null)
+ * @method array|null        hexpireat(string $key, int $unixTimeSeconds, array $fields, string $flag = null)
+ * @method array|null        hexpiretime(string $key, array $fields)
+ * @method array|null        hpersist(string $key, array $fields)
+ * @method array|null        hpexpire(string $key, int $milliseconds, array $fields, string $flag = null)
+ * @method array|null        hpexpireat(string $key, int $unixTimeMilliseconds, array $fields, string $flag = null)
+ * @method array|null        hpexpiretime(string $key, array $fields)
  * @method string|null       hget(string $key, string $field)
+ * @method array|null        hgetex(string $key, array $fields, string $modifier = HGETEX::NULL, int|bool $modifierValue = false)
  * @method array             hgetall(string $key)
+ * @method array             hgetdel(string $key, array $fields)
  * @method int               hincrby(string $key, string $field, int $increment)
  * @method string            hincrbyfloat(string $key, string $field, int|float $increment)
  * @method array             hkeys(string $key)
@@ -172,9 +185,12 @@ use Predis\Response\Status;
  * @method array             hmget(string $key, array $fields)
  * @method mixed             hmset(string $key, array $dictionary)
  * @method array             hrandfield(string $key, int $count = 1, bool $withValues = false)
- * @method array             hscan(string $key, $cursor, array $options = null)
+ * @method array             hscan(string $key, $cursor, ?array $options = null)
  * @method int               hset(string $key, string $field, string $value)
+ * @method int               hsetex(string $key, array $fieldValueMap, string $setModifier = HSETEX::SET_NULL, string $ttlModifier = HSETEX::TTL_NULL, int|bool $ttlModifierValue = false)
  * @method int               hsetnx(string $key, string $field, string $value)
+ * @method array|null        httl(string $key, array $fields)
+ * @method array|null        hpttl(string $key, array $fields)
  * @method array             hvals(string $key)
  * @method int               hstrlen(string $key, string $field)
  * @method array             jsonarrappend(string $key, string $path = '$', ...$value)
@@ -231,10 +247,10 @@ use Predis\Response\Status;
  * @method string[]          smembers(string $key)
  * @method array             smismember(string $key, string ...$members)
  * @method int               smove(string $source, string $destination, string $member)
- * @method string|array|null spop(string $key, int $count = null)
- * @method string|null       srandmember(string $key, int $count = null)
+ * @method string|array|null spop(string $key, ?int $count = null)
+ * @method string|null       srandmember(string $key, ?int $count = null)
  * @method int               srem(string $key, array|string $member)
- * @method array             sscan(string $key, int $cursor, array $options = null)
+ * @method array             sscan(string $key, int $cursor, ?array $options = null)
  * @method string[]          sunion(array|string $keys)
  * @method int               sunionstore(string $destination, array|string $keys)
  * @method int               touch(string[]|string $keyOrKeys, string ...$keys = null)
@@ -265,7 +281,7 @@ use Predis\Response\Status;
  * @method int               tsdecrby(string $key, float $value, ?DecrByArguments $arguments = null)
  * @method int               tsdel(string $key, int $fromTimestamp, int $toTimestamp)
  * @method Status            tsdeleterule(string $sourceKey, string $destKey)
- * @method array             tsget(string $key, GetArguments $arguments = null)
+ * @method array             tsget(string $key, ?GetArguments $arguments = null)
  * @method int               tsincrby(string $key, float $value, ?IncrByArguments $arguments = null)
  * @method array             tsinfo(string $key, ?InfoArguments $arguments = null)
  * @method array             tsmadd(mixed ...$keyTimestampValue)
@@ -275,15 +291,16 @@ use Predis\Response\Status;
  * @method array             tsqueryindex(string ...$filterExpression)
  * @method array             tsrange(string $key, $fromTimestamp, $toTimestamp, ?RangeArguments $arguments = null)
  * @method array             tsrevrange(string $key, $fromTimestamp, $toTimestamp, ?RangeArguments $arguments = null)
- * @method string            xadd(string $key, array $dictionary, string $id = '*', array $options = null)
+ * @method string            xadd(string $key, array $dictionary, string $id = '*', ?array $options = null)
  * @method int               xdel(string $key, string ...$id)
  * @method int               xlen(string $key)
  * @method array             xrevrange(string $key, string $end, string $start, ?int $count = null)
  * @method array             xrange(string $key, string $start, string $end, ?int $count = null)
- * @method string            xtrim(string $key, array|string $strategy, string $threshold, array $options = null)
+ * @method string            xtrim(string $key, array|string $strategy, string $threshold, ?array $options = null)
+ * @method array|null        xread(int $count = null, int $block = null, array $streams = null, string ...$id)
  * @method int               zadd(string $key, array $membersAndScoresDictionary)
  * @method int               zcard(string $key)
- * @method string            zcount(string $key, int|string $min, int|string $max)
+ * @method int               zcount(string $key, int|string $min, int|string $max)
  * @method array             zdiff(array $keys, bool $withScores = false)
  * @method int               zdiffstore(string $destination, array $keys)
  * @method string            zincrby(string $key, int $increment, string $member)
@@ -295,22 +312,22 @@ use Predis\Response\Status;
  * @method array             zpopmin(string $key, int $count = 1)
  * @method array             zpopmax(string $key, int $count = 1)
  * @method mixed             zrandmember(string $key, int $count = 1, bool $withScores = false)
- * @method array             zrange(string $key, int|string $start, int|string $stop, array $options = null)
- * @method array             zrangebyscore(string $key, int|string $min, int|string $max, array $options = null)
+ * @method array             zrange(string $key, int|string $start, int|string $stop, ?array $options = null)
+ * @method array             zrangebyscore(string $key, int|string $min, int|string $max, ?array $options = null)
  * @method int               zrangestore(string $destination, string $source, int|string $min, int|string $max, string|bool $by = false, bool $reversed = false, bool $limit = false, int $offset = 0, int $count = 0)
  * @method int|null          zrank(string $key, string $member)
  * @method int               zrem(string $key, string ...$member)
  * @method int               zremrangebyrank(string $key, int|string $start, int|string $stop)
  * @method int               zremrangebyscore(string $key, int|string $min, int|string $max)
- * @method array             zrevrange(string $key, int|string $start, int|string $stop, array $options = null)
- * @method array             zrevrangebyscore(string $key, int|string $max, int|string $min, array $options = null)
+ * @method array             zrevrange(string $key, int|string $start, int|string $stop, ?array $options = null)
+ * @method array             zrevrangebyscore(string $key, int|string $max, int|string $min, ?array $options = null)
  * @method int|null          zrevrank(string $key, string $member)
  * @method array             zunion(array $keys, int[] $weights = [], string $aggregate = 'sum', bool $withScores = false)
  * @method int               zunionstore(string $destination, array $keys, int[] $weights = [], string $aggregate = 'sum')
  * @method string|null       zscore(string $key, string $member)
- * @method array             zscan(string $key, int $cursor, array $options = null)
- * @method array             zrangebylex(string $key, string $start, string $stop, array $options = null)
- * @method array             zrevrangebylex(string $key, string $start, string $stop, array $options = null)
+ * @method array             zscan(string $key, int $cursor, ?array $options = null)
+ * @method array             zrangebylex(string $key, string $start, string $stop, ?array $options = null)
+ * @method array             zrevrangebylex(string $key, string $start, string $stop, ?array $options = null)
  * @method int               zremrangebylex(string $key, string $min, string $max)
  * @method int               zlexcount(string $key, string $min, string $max)
  * @method int               pexpiretime(string $key)
@@ -324,16 +341,16 @@ use Predis\Response\Status;
  * @method mixed             multi()
  * @method mixed             unwatch()
  * @method array             waitaof(int $numLocal, int $numReplicas, int $timeout)
- * @method mixed             watch(string $key)
+ * @method mixed             watch(string[]|string $keyOrKeys)
  * @method mixed             eval(string $script, int $numkeys, string ...$keyOrArg = null)
  * @method mixed             eval_ro(string $script, array $keys, ...$argument)
  * @method mixed             evalsha(string $script, int $numkeys, string ...$keyOrArg = null)
  * @method mixed             evalsha_ro(string $sha1, array $keys, ...$argument)
  * @method mixed             script($subcommand, $argument = null)
- * @method Status            shutdown(bool $noSave = null, bool $now = false, bool $force = false, bool $abort = false)
+ * @method Status            shutdown(?bool $noSave = null, bool $now = false, bool $force = false, bool $abort = false)
  * @method mixed             auth(string $password)
  * @method string            echo(string $message)
- * @method mixed             ping(string $message = null)
+ * @method mixed             ping(?string $message = null)
  * @method mixed             select(int $database)
  * @method mixed             bgrewriteaof()
  * @method mixed             bgsave()
@@ -353,8 +370,8 @@ use Predis\Response\Status;
  * @method array             geohash(string $key, array $members)
  * @method array             geopos(string $key, array $members)
  * @method string|null       geodist(string $key, $member1, $member2, $unit = null)
- * @method array             georadius(string $key, $longitude, $latitude, $radius, $unit, array $options = null)
- * @method array             georadiusbymember(string $key, $member, $radius, $unit, array $options = null)
+ * @method array             georadius(string $key, $longitude, $latitude, $radius, $unit, ?array $options = null)
+ * @method array             georadiusbymember(string $key, $member, $radius, $unit, ?array $options = null)
  * @method array             geosearch(string $key, FromInterface $from, ByInterface $by, ?string $sorting = null, int $count = -1, bool $any = false, bool $withCoord = false, bool $withDist = false, bool $withHash = false)
  * @method int               geosearchstore(string $destination, string $source, FromInterface $from, ByInterface $by, ?string $sorting = null, int $count = -1, bool $any = false, bool $storeDist = false)
  *
@@ -365,6 +382,8 @@ use Predis\Response\Status;
  * @property FTCURSOR          $ftcursor
  * @property JSONDEBUG         $jsondebug
  * @property ACL               $acl
+ *
+ * @no-named-arguments
  */
 interface ClientInterface
 {
