@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -175,7 +175,7 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
         return [
             'scheme' => 'tcp',
             'host' => constant('REDIS_SERVER_HOST'),
-            'port' => constant('REDIS_SERVER_PORT'),
+            'port' => ($this->isStackTest()) ? getenv('REDIS_STACK_SERVER_PORT') : constant('REDIS_SERVER_PORT'),
             'database' => constant('REDIS_SERVER_DBNUM'),
         ];
     }
@@ -584,6 +584,22 @@ abstract class PredisTestCase extends PHPUnit\Framework\TestCase
             && in_array('cluster', $annotations['method']['group'], true);
     }
 
+    /**
+     * Check annotations if it's matches to stack test scenario.
+     *
+     * @return bool
+     */
+    protected function isStackTest(): bool
+    {
+        $annotations = TestUtil::parseTestMethodAnnotations(
+            get_class($this),
+            $this->getName(false)
+        );
+
+        return isset($annotations['class']['group'])
+        && in_array('realm-stack', $annotations['class']['group'], true);
+    }
+
     /**
      * Parse comma-separated cluster endpoints and convert them into tcp strings.
      *
