@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -1008,6 +1008,14 @@ class KeyPrefixProcessorTest extends PredisTestCase
                 ['key', 'MAXLEN', 100],
                 ['prefix:key', 'MAXLEN', 100],
             ],
+            ['ZPOPMIN',
+                ['key'],
+                ['prefix:key'],
+            ],
+            ['ZPOPMAX',
+                ['key'],
+                ['prefix:key'],
+            ],
             /* ---------------- Redis 6.2 ---------------- */
             ['GETDEL',
                 ['key'],
