@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,6 +12,8 @@
 
 namespace Predis\Command\Redis;
 
+use Predis\Response\ServerException;
+
 /**
  * @group commands
  * @group realm-server
@@ -137,6 +139,48 @@ class CONFIG_Test extends PredisCommandTestCase
         $redis->config('SET', 'loglevel', $previous['loglevel']);
     }
 
+    /**
+     * @group connected
+     * @group relay-incompatible
+     * @requiresRedisVersion >= 7.9.0
+     */
+    public function testOverrideDefaultDialectWithConfigCommand()
+    {
+        $redis = $this->getClient();
+        $default_dialect = (int) $redis
+            ->config('GET', 'search-default-dialect')['search-default-dialect'];
+
+        $this->assertEquals('OK', $redis->config('SET', 'search-default-dialect', 2));
+        $this->assertEquals(2, (int) $redis->ftconfig->get('DEFAULT_DIALECT')[0][1]);
+        $this->assertEquals(2,
+            (int) $redis->config('GET', 'search-default-dialect')['search-default-dialect']);
+        $this->assertEquals(
+            'OK',
+            $redis->config('SET', 'search-default-dialect', $default_dialect)
+        );
+    }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 7.9.0
+     */
+    public function testSetGetSearchConfiguration()
+    {
+        $redis = $this->getClient();
+
+        $this->assertGreaterThan(0,
+            (int) $redis->config('GET', 'search-timeout')['search-timeout']);
+        $this->assertGreaterThanOrEqual(0,
+            (int) $redis->config('GET', 'ts-retention-policy')['ts-retention-policy']);
+        $this->assertGreaterThanOrEqual(0,
+            (int) $redis->config('GET', 'bf-error-rate')['bf-error-rate']);
+        $this->assertGreaterThan(0,
+            (int) $redis->config('GET', 'cf-initial-size')['cf-initial-size']);
+
+        $this->expectException(ServerException::class);
+        $redis->config('SET', 'search-max-doctablesize', 10000);
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.0.0
