@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -78,13 +78,13 @@ class FTDICTDUMP_Test extends PredisCommandTestCase
      * @group connected
      * @return void
      * @requiresRediSearchVersion >= 1.4.0
+     * @requiresRedisVersion <= 7.9.0
      */
     public function testThrowsExceptionOnNonExistingDictionary(): void
     {
         $redis = $this->getClient();
 
         $this->expectException(ServerException::class);
-        $this->expectExceptionMessage('could not open dict key');
 
         $redis->ftdictdump('dict');
     }
