@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2025 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -123,23 +123,6 @@ class StreamConnectionTest extends PredisConnectionTestCase
         $connection1->disconnect();
     }
 
-    /**
-     * @group connected
-     * @requires PHP 5.4
-     */
-    public function testPersistentConnectionsToSameNodeShareResource(): void
-    {
-        $connection1 = $this->createConnectionWithParams(['persistent' => true]);
-        $connection2 = $this->createConnectionWithParams(['persistent' => true]);
-
-        $this->assertPersistentConnection($connection1);
-        $this->assertPersistentConnection($connection2);
-
-        $this->assertSame($connection1->getResource(), $connection2->getResource());
-
-        $connection1->disconnect();
-    }
-
     /**
      * @group connected
      * @requires PHP 5.4
